@@ -1,4 +1,5 @@
 # oppia/context_processors.py
+from django.conf import settings
 import oppia
 from oppia.models import Points, Award
 
@@ -17,3 +18,9 @@ def get_points(request):
 def get_version(request):
     version = "v" + str(oppia.VERSION[0]) + "." + str(oppia.VERSION[1]) + "." + str(oppia.VERSION[2])
     return {'version': version }
+
+def get_settings(request):
+    return { 'OPPIA_ALLOW_SELF_REGISTRATION': settings.OPPIA_ALLOW_SELF_REGISTRATION,
+             'OPPIA_GOOGLE_ANALYTICS_ENABLED': settings.OPPIA_GOOGLE_ANALYTICS_ENABLED,
+             'OPPIA_GOOGLE_ANALYTICS_CODE': settings.OPPIA_GOOGLE_ANALYTICS_CODE,
+             'OPPIA_GOOGLE_ANALYTICS_DOMAIN': settings.OPPIA_GOOGLE_ANALYTICS_DOMAIN,}
